==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/vorbis/translations/vorbis_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_TW">
<defaultcodec></defaultcodec>
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="31"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis 插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="33"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis 檔案</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="90"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>關於 Ogg Vorbis 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="91"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg Vorbis 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="92"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="94"/>
        <source>Source code based on mq3 progect</source>
        <translation>源碼基於 mq3 項目</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="61"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="273"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Track number:</source>
        <translation>音軌：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="296"/>
        <source>Year:</source>
        <translation>年代：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="306"/>
        <source>Genre:</source>
        <translation>流派：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="316"/>
        <source>Comment:</source>
        <translation>備註：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="326"/>
        <source>Album:</source>
        <translation>專輯：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="336"/>
        <source>Artist:</source>
        <translation>藝術家：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="346"/>
        <source>Title:</source>
        <translation>標題：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="387"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="197"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="227"/>
        <source>File size:</source>
        <translation>檔案大小：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="100"/>
        <source>Sample rate:</source>
        <translation>取樣率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>檔案路徑：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>Ogg Vorbis Info</source>
        <translation>Ogg Vorbis 資訊</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="83"/>
        <source>Length:</source>
        <translation>長度：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="120"/>
        <source>Channels:</source>
        <translation>音頻通道：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="143"/>
        <source>Bit Rate</source>
        <translation>位速率</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="187"/>
        <source>Minimum:</source>
        <translation>最小位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="204"/>
        <source>Maximum:</source>
        <translation>最大位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="214"/>
        <source>Nominal:</source>
        <translation>名義位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="246"/>
        <source>Ogg Vorbis Tag</source>
        <translation>Ogg Vorbis 標簽</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="69"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="70"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>詳細資料</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/vorbis/translations/vorbis_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis 插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis 檔案</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="113"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>關於 Ogg Vorbis 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="114"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg Vorbis 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="115"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="116"/>
        <source>Source code based on mq3 progect</source>
        <translation>源碼基於 mq3 項目</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="61"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="273"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Track number:</source>
        <translation>音軌：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="296"/>
        <source>Year:</source>
        <translation>年代：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="306"/>
        <source>Genre:</source>
        <translation>流派：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="316"/>
        <source>Comment:</source>
        <translation>備註：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="326"/>
        <source>Album:</source>
        <translation>專輯：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="336"/>
        <source>Artist:</source>
        <translation>藝術家：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="346"/>
        <source>Title:</source>
        <translation>標題：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="387"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="66"/>
        <location filename="../detailsdialog.ui" line="76"/>
        <location filename="../detailsdialog.ui" line="93"/>
        <location filename="../detailsdialog.ui" line="110"/>
        <location filename="../detailsdialog.ui" line="170"/>
        <location filename="../detailsdialog.ui" line="177"/>
        <location filename="../detailsdialog.ui" line="197"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="227"/>
        <source>File size:</source>
        <translation>檔案大小：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="100"/>
        <source>Sample rate:</source>
        <translation>取樣率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>檔案路徑：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>Ogg Vorbis Info</source>
        <translation>Ogg Vorbis 資訊</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="83"/>
        <source>Length:</source>
        <translation>長度：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="120"/>
        <source>Channels:</source>
        <translation>音頻通道：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="143"/>
        <source>Bit Rate</source>
        <translation>位速率</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="187"/>
        <source>Minimum:</source>
        <translation>最小位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="204"/>
        <source>Maximum:</source>
        <translation>最大位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="214"/>
        <source>Nominal:</source>
        <translation>名義位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="246"/>
        <source>Ogg Vorbis Tag</source>
        <translation>Ogg Vorbis 標簽</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="65"/>
        <location filename="../detailsdialog.cpp" line="67"/>
        <location filename="../detailsdialog.cpp" line="69"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="70"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>詳細資料</translation>
    </message>
</context>
</TS>
